littlemcmc.QuadPotentialFull
============================

.. currentmodule:: littlemcmc

.. autoclass:: QuadPotentialFull

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QuadPotentialFull.__init__
      ~QuadPotentialFull.energy
      ~QuadPotentialFull.raise_ok
      ~QuadPotentialFull.random
      ~QuadPotentialFull.reset
      ~QuadPotentialFull.update
      ~QuadPotentialFull.velocity
      ~QuadPotentialFull.velocity_energy
   
   

   
   
   